@@ -17,6 +17,8 @@
 namespace v8 {
 namespace internal {
 
+#include "src/codegen/define-code-stub-assembler-macros.inc"
+
 class IntlBuiltinsAssembler : public CodeStubAssembler {
  public:
   explicit IntlBuiltinsAssembler(compiler::CodeAssemblerState* state)
@@ -76,7 +78,7 @@ class IntlBuiltinsAssembler : public CodeStubAssembler {
   };
   void ToLowerCaseImpl(TNode<String> string, TNode<Object> maybe_locales,
                        TNode<Context> context, ToLowerCaseKind kind,
-                       std::function<void(TNode<Object>)> ReturnFct);
+                       std::function<void(TNode<JSAny>)> ReturnFct);
 };
 
 TF_BUILTIN(StringToLowerCaseIntl, IntlBuiltinsAssembler) {
@@ -107,12 +109,12 @@ TF_BUILTIN(StringPrototypeToLocaleLowerCase, IntlBuiltinsAssembler) {
       ToThisString(context, maybe_string, "String.prototype.toLocaleLowerCase");
   ToLowerCaseImpl(string, maybe_locales, context,
                   ToLowerCaseKind::kToLocaleLowerCase,
-                  [&args](TNode<Object> ret) { args.PopAndReturn(ret); });
+                  [&args](TNode<JSAny> ret) { args.PopAndReturn(ret); });
 }
 
 void IntlBuiltinsAssembler::ToLowerCaseImpl(
     TNode<String> string, TNode<Object> maybe_locales, TNode<Context> context,
-    ToLowerCaseKind kind, std::function<void(TNode<Object>)> ReturnFct) {
+    ToLowerCaseKind kind, std::function<void(TNode<JSAny>)> ReturnFct) {
   Label call_c(this), return_string(this), runtime(this, Label::kDeferred);
 
   // Unpack strings if possible, and bail to runtime unless we get a one-byte
@@ -230,12 +232,12 @@ void IntlBuiltinsAssembler::ToLowerCaseImpl(
 
   BIND(&runtime);
   if (kind == ToLowerCaseKind::kToLocaleLowerCase) {
-    ReturnFct(CallRuntime(Runtime::kStringToLocaleLowerCase, context, string,
-                          maybe_locales));
+    ReturnFct(CallRuntime<JSAny>(Runtime::kStringToLocaleLowerCase, context,
+                                 string, maybe_locales));
   } else {
     DCHECK_EQ(kind, ToLowerCaseKind::kToLowerCase);
-    ReturnFct(CallRuntime(Runtime::kStringToLowerCaseIntl, NoContextConstant(),
-                          string));
+    ReturnFct(CallRuntime<JSAny>(Runtime::kStringToLowerCaseIntl,
+                                 NoContextConstant(), string));
   }
 }
 
@@ -263,7 +265,7 @@ void IntlBuiltinsAssembler::ListFormatCommon(TNode<Context> context,
 
     // 6. Return ? FormatList(lf, stringList).
     args.PopAndReturn(
-        CallRuntime(format_func_id, context, list_format, string_list));
+        CallRuntime<JSAny>(format_func_id, context, list_format, string_list));
   }
 }
 
@@ -289,5 +291,7 @@ TF_BUILTIN(ListFormatPrototypeFormatToParts, IntlBuiltinsAssembler) {
       Runtime::kFormatListToParts, "Intl.ListFormat.prototype.formatToParts");
 }
 
+#include "src/codegen/undef-code-stub-assembler-macros.inc"
+
 }  // namespace internal
 }  // namespace v8
