@@ -925,7 +925,7 @@ class ReadableStreamBYOBReader {
       throw new ERR_INVALID_ARG_TYPE('stream', 'ReadableStream', stream);
     this[kState] = {
       stream: undefined,
-      requestIntoRequests: [],
+      readIntoRequests: [],
       close: {
         promise: undefined,
         resolve: undefined,
@@ -1031,7 +1031,7 @@ class ReadableStreamBYOBReader {
   [kInspect](depth, options) {
     return customInspect(depth, options, this[kType], {
       stream: this[kState].stream,
-      requestIntoRequests: this[kState].requestIntoRequests.length,
+      readIntoRequests: this[kState].readIntoRequests.length,
       close: this[kState].close.promise,
     });
   }
