@@ -84,7 +84,7 @@ const { getOptionValue } = require('internal/options');
 const binding = internalBinding('util');
 
 const {
-  deprecate,
+  deprecate: internalDeprecate,
   getLazy,
   getSystemErrorMap,
   getSystemErrorName: internalErrorName,
@@ -339,7 +339,7 @@ function _errnoException(...args) {
     Error.stackTraceLimit = 0;
     const e = new ErrnoException(...args);
     Error.stackTraceLimit = limit;
-    ErrorCaptureStackTrace(e, _exceptionWithHostPort);
+    ErrorCaptureStackTrace(e, _errnoException);
     return e;
   }
   return new ErrnoException(...args);
@@ -459,13 +459,18 @@ function getCallSites(frameCount = 10, options) {
   return binding.getCallSites(frameCount);
 };
 
+// Public util.deprecate API
+function deprecate(fn, msg, code, { modifyPrototype } = {}) {
+  return internalDeprecate(fn, msg, code, undefined, modifyPrototype);
+}
+
 // Keep the `exports =` so that various functions can still be monkeypatched
 module.exports = {
   _errnoException,
   _exceptionWithHostPort,
-  _extend: deprecate(_extend,
-                     'The `util._extend` API is deprecated. Please use Object.assign() instead.',
-                     'DEP0060'),
+  _extend: internalDeprecate(_extend,
+                             'The `util._extend` API is deprecated. Please use Object.assign() instead.',
+                             'DEP0060'),
   callbackify,
   debug: debuglog,
   debuglog,
@@ -473,26 +478,20 @@ module.exports = {
   format,
   styleText,
   formatWithOptions,
-  // Deprecated getCallSite.
-  // This API can be removed in next semver-minor release.
-  getCallSite: deprecate(getCallSites,
-                         'The `util.getCallSite` API has been renamed to `util.getCallSites()`.',
-                         'ExperimentalWarning'),
   getCallSites,
   getSystemErrorMap,
   getSystemErrorName,
   getSystemErrorMessage,
   inherits,
   inspect,
-  isArray: deprecate(ArrayIsArray,
-                     'The `util.isArray` API is deprecated. Please use `Array.isArray()` instead.',
-                     'DEP0044'),
-  isDeepStrictEqual(a, b) {
+  isArray: internalDeprecate(ArrayIsArray,
+                             'The `util.isArray` API is deprecated. Please use `Array.isArray()` instead.',
+                             'DEP0044'),
+  isDeepStrictEqual(a, b, skipPrototype) {
     if (internalDeepEqual === undefined) {
-      internalDeepEqual = require('internal/util/comparisons')
-        .isDeepStrictEqual;
+      internalDeepEqual = require('internal/util/comparisons').isDeepStrictEqual;
     }
-    return internalDeepEqual(a, b);
+    return internalDeepEqual(a, b, skipPrototype);
   },
   promisify,
   stripVTControlCharacters,
