@@ -10,24 +10,26 @@ const assert = require('assert');
 const fixtures = require('../common/fixtures');
 const { NodeInstance } = require('../common/inspector-helper.js');
 
-async function runIfWaitingForDebugger(session) {
-  const commands = [
-    { 'method': 'Runtime.enable' },
-    { 'method': 'Debugger.enable' },
-    { 'method': 'Runtime.runIfWaitingForDebugger' },
-  ];
-
-  await session.send(commands);
-}
-
 async function runTest() {
   const main = fixtures.path('es-module-loaders', 'register-loader.mjs');
+  process.env.NODE_DEBUG = 'esm,async_loader_worker';
   const child = new NodeInstance(['--inspect-wait=0'], '', main);
 
   const session = await child.connectInspectorSession();
-  await runIfWaitingForDebugger(session);
+  await session.send({ method: 'NodeRuntime.enable' });
+  await session.waitForNotification('NodeRuntime.waitingForDebugger');
+  await session.send([
+    { 'method': 'Runtime.enable' },
+    { 'method': 'Debugger.enable' },
+    { 'method': 'Runtime.runIfWaitingForDebugger' },
+  ]);
+  await session.send({ method: 'NodeRuntime.disable' });
   await session.waitForDisconnect();
-  assert.strictEqual((await child.expectShutdown()).exitCode, 0);
+  const result = await child.expectShutdown();
+  assert.deepStrictEqual(result, {
+    exitCode: 0,
+    signal: null,
+  });
 }
 
 runTest();
